/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

[scriptable, builtinclass, uuid(8b4ed443-a6b0-4445-aab0-9aa9fd5f6c1e)]
interface nsIDOMDataErrorEvent : nsIDOMEvent
{
  readonly attribute DOMString message;

  [noscript] void initDataErrorEvent(in DOMString aType,
                                     in boolean aCanBubble,
                                     in boolean aCancelable,
                                     in DOMString aMessage);
};

dictionary DataErrorEventInit : EventInit
{
  DOMString message;
};
