/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
#include "nsISupports.idl"

[scriptable, uuid(050cdc00-3b8e-11d3-9ce4-a458f454fcbc)]
interface nsIDocumentStateListener : nsISupports
{

	void        NotifyDocumentCreated();
	void        NotifyDocumentWillBeDestroyed();
	void        NotifyDocumentStateChanged(in boolean nowDirty);

};
